California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 008 - ELIMINATES RIGHT OF SAME-SEX COUPLES TO MARRY. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1302592 | PROTECTMARRIAGE.COM - YES ON 8, A PROJECT OF CALIFORNIA RENEWAL | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1303282 | NATIONAL ORGANIZATION FOR MARRIAGE CALIFORNIA - YES ON 8, SPONSORED BY NATIONAL ORGANIZATION FOR MARRIAGE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1259396 | NO ON 8, EQUALITY FOR ALL | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308367 | CALIFORNIANS FOR TRADITIONAL MARRIAGE COMMITTEE FOR PROPOSITION 8 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1309338 | YES ON PROPOSITION 8, SPONSORED BY CAPITOL RESOURCE FAMILY IMPACT | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308436 | PROTECT MARRIAGE FOR ALL, SPONSORED BY WITH LIBERTY AND JUSTICE FOR ALL | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308401 | BIGOTS AGAINST LIFE, LIBERTY AND THE PURSUIT OF HAPPINESS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308414 | LOG CABIN REPUBLICANS AGAINST 8 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1313185 | FAMILY RESEARCH COUNCIL | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307834 | GLBT ALLIANCE OF SANTA CRUZ COUNTY PAC, THE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1301054 | CALIFORNIANS FOR MARRIAGE, YES ON PROPOSITION 8, SPONSORED BY THE ALLIANCE FOR MARRIAGE FOUNDATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1312996 | CAMPAIGN AGAINST PROPOSITIONS 4, 6, 8, 9, & FOR PROPOSITION 5 CALIFORNIANS FOR JUSTICE EDUCATION FUND | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1313175 | STAND FOR MARRIAGE CALIFORNIA, A COMMITTEE FOR PROPOSITION 8, SPONSORED BY STAND FOR MARRIAGE, INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307950 | TASK FORCE CALIFORNIA COMMITTEE - NO ON 8 - SPONSORED BY THE NATIONAL GAY AND LESBIAN TASK FORCE FOUNDATION/ACTION FUND | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1309109 | SANTA CLARA COUNTY COMMITTEE AGAINST PROPOSITION 8 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1310774 | WINE COUNTRY COMMITTEE AGAINST PROPOSITION 8 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1312536 | ADVENTISTS FOR PROPOSITION 8 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308829 | NO ON 8 - MARRIAGE EQUALITY USA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1309082 | HIGH DESERT YES ON 8 A COMMITTEE FOR PROP 8 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1301573 | CALIFORNIA MARRIAGE EQUALITY PAC - SPONSORED BY EQUALITY CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307246 | HUMAN RIGHTS CAMPAIGN CALIFORNIA MARRIAGE PAC - NO ON PROP 8 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308178 | NO ON PROPOSITION 8, CAMPAIGN FOR MARRIAGE EQUALITY, A PROJECT OF THE AMERICAN CIVIL LIBERTIES UNION OF NORTHERN CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1311419 | VOTE NO ON PROPS. 4 & 8, SPONSORED BY FEMINIST MAJORITY FOUNDATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1312672 | COUNCIL OF CHURCHES OF SANTA CLARA COUNTY COMMITTEE AGAINST PROPOSITION 8 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1312752 | CONVENCION DE IGLESIAS BAUTISTAS HISPANAS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307787 | CALIFORNIANS AGAINST ELIMINATING BASIC RIGHTS, NO ON PROP. 8 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308206 | NO ON 8, NATIONAL CENTER FOR LESBIAN RIGHTS SOCIAL JUSTICE FUND | OPPOSE